10020 - No body given

### Navigation

- index
- next |
- previous |
- fantastico 0.5.0-b126 documentation »
- Fantastico features »
- ROA (Resource Oriented Architecture) »
- ROA Technical Summary »

# 10020 - No body given

Whenever we try to create / update a resource without sending resource body (information about the resource) this response is received. Below you can see a sample error response:

    {"error_code": 10020,
     "error_description": "Friendly error description.",
     "error_details": <link to this page>}